<?php

declare(strict_types=1);

namespace Dedi\SyliusImportExportPlugin\Transformer;

use FriendsOfSylius\SyliusImportExportPlugin\Exporter\Transformer\Handler;
use Sylius\Component\Currency\Context\CurrencyContextInterface;
use Sylius\Component\Locale\Context\LocaleContextInterface;

final class IntegerToMoneyFormatHandler extends Handler
{
    private LocaleContextInterface $localeContext;
    private CurrencyContextInterface $currencyContext;
    private array $keys;

    /**
     * @param string[] $allowedKeys
     */
    public function __construct(LocaleContextInterface $localeContext, CurrencyContextInterface $currencyContext, array $allowedKeys)
    {
        $this->localeContext = $localeContext;
        $this->currencyContext = $currencyContext;
        $this->keys = $allowedKeys;
    }

    /**
     * @inheritdoc
     */
    protected function process($key, $value): ?string
    {
        $formatter = new \NumberFormatter($this->localeContext->getLocaleCode(), \NumberFormatter::CURRENCY);

        return $formatter->formatCurrency($value / 100, $this->currencyContext->getCurrencyCode());
    }

    protected function allows($key, $value): bool
    {
        return is_int($value) && in_array($key, $this->keys, true);
    }
}
